@@ -4,9 +4,10 @@ from netbox_storage.api.views import (
     NetboxStorageRootView,
     DriveViewSet,
     FilesystemViewSet,
-    LinuxVolumeViewSet,
+    LogicalVolumeViewSet,
     PartitionViewSet,
     PhysicalVolumeViewSet,
+    VolumeGroupViewSet
 )
 
 router = NetBoxRouter()
@@ -14,8 +15,9 @@ router.APIRootView = NetboxStorageRootView
 
 router.register("drive", DriveViewSet)
 router.register("filesystem", FilesystemViewSet)
-router.register("linuxvolume", LinuxVolumeViewSet)
+router.register("logicalvolume", LogicalVolumeViewSet)
 router.register("partition", PartitionViewSet)
 router.register("physicalvolume", PhysicalVolumeViewSet)
+router.register("volumegroup", VolumeGroupViewSet)
 
 urlpatterns = router.urls
