@@ -21,18 +21,20 @@ from virtualization.models import Cluster, ClusterType, VirtualMachine
 
 class DriveForm(NetBoxModelForm):
     """Form for creating a new Drive object."""
-    ct = ClusterType.objects.filter(name="Storage").values_list('id', flat=True)[0]
+    #ct = ClusterType.objects.filter(name="Storage").values_list('id', flat=True)[0]
     size = IntegerField(
         label="Size (GB)",
         help_text="The size of the drive e.g. 25",
         validators=[MinValueValidator(1)],
     )
+    cluster_type = DynamicModelChoiceField(
+        queryset=ClusterType.objects.all(),
+        help_text="The Cluster Type of the drive",
+    )
     cluster = DynamicModelChoiceField(
-        queryset=Cluster.objects.all(
-            # type__pk=ClusterType.objects.filter(name="Storage").values_list('id', flat=True)[0]
-        ),
+        queryset=Cluster.objects.all(),
         query_params={
-            'type_id': ct,
+            'type_id': '$cluster_type' # ClusterType.objects.filter(name="Storage").values_list('id', flat=True)[0]
         },
         help_text="The Storage Cluster of the drive",
     )
@@ -46,6 +48,24 @@ class DriveForm(NetBoxModelForm):
         help_text="Short Description e.g. Hard Drive 1 on SSD Cluster",
     )
 
+    fieldsets = (
+        (
+            "Drive Cluster Config",
+            (
+                "cluster_type",
+                "cluster",
+            ),
+        ),
+        (
+            "Drive Configuration",
+            (
+                "size",
+                "virtual_machine",
+                "description",
+            ),
+        ),
+    )
+
     class Meta:
         model = Drive
 
